Page 98 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 98

Home

    would be willing to tell this to the American people he
    responded that, "This we would not think of doing." To
    this day that objective of merging the United States with
    the Soviet Union has not been abandoned.

    Many of the 210 men who became original members
    of the Council on Foreign Relations were supporters of
    the Bolshevik Revolution in Russia in 1917. It was

    support from these wealthy businessmen in the United
    States that helped make the revolution successful.
    Jacob Schiff, head of the New York based Kuhn,

    Loeb and Co., spent $20 million on the revolution.
    Federal Reserve Director, William Boyce Thompson,
    gave the Bolsheviks $1 million. In the summer of 1917,
    fifteen Wall Street financiers and attorneys, led by

    Thompson, went to Petrograd, the center of revolutionary
    activity. This was disguised as a Red Cross Mission by
    taking along a few doctors and nurses. Disillusioned, the
    doctors and nurses returned home within a month; the

    financiers stayed from June to November.
    After the Revolution in Russia was successful, many

    American businessmen who supported it went into
    business with the Soviets. Averell Harriman formed a

    joint shipping firm with the Soviets. The Rockefeller
    family became involved in the oil business with the
    Soviets. From the 1920s the Rockefeller's Chase Bank

    financed business in the Soviet Union. Today the
    Rockefeller's Chase Manhattan Bank maintains a branch

    93

    Building Modern Babylon

    When Norman Dodd asked Rowan Gaither if he

    financed business in the Soviet Union.

    office at 1 Karl Marx Square in Moscow.